<?php
/**
 * @file
 * Contains the Morris display plugin.
 *
 * @author Adrian Rollett
 */

/**
 * The plugin that handles the Morris style.
 *
 * @ingroup views_style_plugins
 */
class morris_views_plugin_style_morris extends views_plugin_style {
  function option_definition () {
    $options = parent::option_definition();

    $options['y_axis'] = array('default' => '');
    $options['width'] = array('default' => 600);
    $options['height'] = array('default' => 400);
    $options['line_width'] = array('default' => 2);
    $options['point_size'] = array('default' => 2);

    return $options;
  }

  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['y_axis'] = array(
      '#type' => 'textfield',
      '#title' => t('Y Axis'),
      '#description' => t('Y Axis Label'),
      '#size' => 20,
      '#required' => TRUE,
      '#default_value' => $this->options['y_axis'],
    );
    $form['width'] = array(
      '#type' => 'textfield',
      '#title' => t('Width'),
      '#description' => t('Graph width in pixels'),
      '#size' => 8,
      '#required' => TRUE,
      '#default_value' => $this->options['width'],
    );
    $form['height'] = array(
      '#type' => 'textfield',
      '#title' => t('Height'),
      '#description' => t('Graph height in pixels'),
      '#size' => 8,
      '#required' => TRUE,
      '#default_value' => $this->options['height'],
    );
    $form['line_width'] = array(
      '#type' => 'textfield',
      '#title' => t('Line Width'),
      '#description' => t('Line width in pixels'),
      '#size' => 2,
      '#required' => TRUE,
      '#default_value' => $this->options['line_width'],
    );
    $form['point_size'] = array(
      '#type' => 'textfield',
      '#title' => t('Point Size'),
      '#description' => t('Point size in pixels'),
      '#size' => 2,
      '#required' => TRUE,
      '#default_value' => $this->options['point_size'],
    );
  }

  function render() {
    $sets = $this->render_grouping($this->view->result, $this->options['grouping']);
    $one = count($sets) == 1;
    $set = 0;
    foreach ($sets as $title => $records) {
      $id = drupal_clean_css_identifier($this->view->name . '-' . $this->display->id . '-' . $set++);
      $title = $one ? $this->view->human_name : $title;
      $width = $this->options['width'];
      $height = $this->options['height'];
      $y_axis = $this->options['y_axis'];

      $data = array();

      foreach ($records as $row_index => $row) {
        foreach ($this->view->field as $key => $field) {
          if (!$field->options['exclude']) {
            $data[] = date('Y-m-d', $row->{$field->field_alias});
          }
        }
      }
      $data = array_count_values($data);
      $x = array_keys($data);
      $y = array_values($data);
      $morris = new Morris();
      $morris->setData($x, array($y), array($y_axis));
      $morris->element = $id;
      $morris->lineWidth = $this->options['line_width'];
      $morris->pointSize = $this->options['point_size'];
      $morris->display();
    }

    return '<div style="width: ' . $width . 'px; height: ' . $height . 'px;" id="' . $id . '" />';
  }
}
